@@ -5,7 +5,7 @@ use utf8;
 
 package CPAN::Changes::Group::Dependencies::Stats;
 
-our $VERSION = '0.002000';
+our $VERSION = '0.002001';
 
 # ABSTRACT: Create a Dependencies::Stats section detailing summarized differences
 
@@ -51,14 +51,12 @@ extends 'CPAN::Changes::Group';
 
 
 
-sub FOREIGNBUILDARGS {
-  my ( undef, @args ) = @_;
-  if ( @args % 2 == 0 ) {
-    my (%args) = @args;
-    $args{'name'} = 'Dependencies::Stats' unless exists $args{'name'};
-    return %args;
+sub name {
+  my ($self) = @_;
+  if ( not exists $self->{'name'} or not length $self->{'name'} ) {
+    $self->{'name'} = 'Dependencies::Stats';
   }
-  return @args;
+  return $self->{'name'};
 }
 
 lsub prelude          => sub { [] };
@@ -243,7 +241,7 @@ CPAN::Changes::Group::Dependencies::Stats - Create a Dependencies::Stats section
 
 =head1 VERSION
 
-version 0.002000
+version 0.002001
 
 =head1 SYNOPSIS
 
